@@ -2,6 +2,7 @@ package version
 
 import (
 	"fmt"
+
 	"github.com/openshift/cluster-svcat-controller-manager-operator/pkg/metrics"
 	"k8s.io/apimachinery/pkg/version"
 )
@@ -19,8 +20,6 @@ var (
 	minorFromGit string
 	// build date in ISO8601 format, output of $(date -u +'%Y-%m-%dT%H:%M:%SZ')
 	buildDate string
-	// SourceGitCommit indicates which git commit the binary was built from
-	SourceGitCommit string
 )
 
 // Get returns the overall codebase version. It's for detecting
@@ -35,9 +34,9 @@ func Get() version.Info {
 	}
 }
 
-// Commit returns a pretty string concatenation of SourceGitCommit
+// Commit returns a pretty string concatenation of commitFromGit
 func Commit() string {
-	return fmt.Sprintf("cluster-svcat-controller-manager-operator source git commit: %s\n", SourceGitCommit)
+	return fmt.Sprintf("cluster-svcat-controller-manager-operator source git commit: %s\n", commitFromGit)
 }
 
 func init() {
